@@ -7,13 +7,13 @@ from selenium.webdriver.support.select import Select
 import re
 from selenium.webdriver.common.by import By
 
-def lemonhd_upload(web,file1,record_path,qbinfo,basic):
+def lemonhd_upload(web,file1,record_path,qbinfo,basic,hashlist):
     if 'anime' in file1.pathinfo.type.lower():
-        return lemonhd_upload_anime(web,file1,record_path,qbinfo,basic)
+        return lemonhd_upload_anime(web,file1,record_path,qbinfo,basic,hashlist)
     elif 'tv' in file1.pathinfo.type.lower():
-        return lemonhd_upload_tv(web,file1,record_path,qbinfo,basic)
+        return lemonhd_upload_tv(web,file1,record_path,qbinfo,basic,hashlist)
     elif 'movie' in file1.pathinfo.type.lower():
-        return lemonhd_upload_tv(web,file1,record_path,qbinfo,basic)
+        return lemonhd_upload_tv(web,file1,record_path,qbinfo,basic,hashlist)
 
 def lemon_check(web):
     logger.info('正在自动审核')
@@ -31,7 +31,7 @@ def lemon_check(web):
         logger.info('审核失败')
         return False
 
-def lemonhd_upload_anime(web,file1,record_path,qbinfo,basic):
+def lemonhd_upload_anime(web,file1,record_path,qbinfo,basic,hashlist):
 
     if (file1.pathinfo.type=='anime' or file1.pathinfo.type=='tv') and file1.pathinfo.collection==0:
         fileinfo=file1.chinesename+'在'+web.site.sitename+'第'+file1.episodename+'集'
@@ -465,32 +465,33 @@ def lemonhd_upload_anime(web,file1,record_path,qbinfo,basic):
 
     if not downloadurl =='':
 
-        res=qbseed(url=downloadurl,filepath=file1.downloadpath,qbinfo=qbinfo,category=file1.pathinfo.category)
+        res=qbseed(url=downloadurl,filepath=file1.downloadpath,qbinfo=qbinfo,category=file1.pathinfo.category,hashlist=hashlist)
         if res:
             logger.info(fileinfo+'种子发布成功,种子链接:'+downloadurl+',当前网址:'+web.driver.current_url)
+            fileinfo=fileinfo+'种子发布成功,'
         else:
             logger.warning(fileinfo+'添加种子失败,种子链接:'+downloadurl+',当前网址:'+web.driver.current_url)
-            return True,fileinfo+'种子发布成功,但是添加种子失败,请手动添加种子，种子链接:'+downloadurl+',当前网址:'+web.driver.current_url
+            fileinfo=fileinfo+'种子发布成功,但是添加种子失败,请手动添加种子,'
+            #return True,fileinfo+'种子发布成功,但是添加种子失败,请手动添加种子，种子链接:'+downloadurl+',当前网址:'+web.driver.current_url
     else:
         logger.warning(fileinfo+'未找到下载链接,当前网址:'+web.driver.current_url)
         return False,fileinfo+'未找到下载链接,当前网址:'+web.driver.current_url
     
     if 'check' in dir(web.site) and web.site.check==False:
-        return True,fileinfo+'种子发布成功,种子链接:'+downloadurl+',当前网址:'+web.driver.current_url
+        return True,fileinfo+'种子链接:'+downloadurl+',当前网址:'+web.driver.current_url
 
     res=lemon_check(web)
     if res:
         logger.info('成功审核第'+file1.episodename+'集的资源')
-        infostr=fileinfo+'种子发布成功,种子链接:'+downloadurl+',当前网址:'+web.driver.current_url+'且成功审核第'+file1.episodename+'集的资源'
+        infostr=fileinfo+'审核成功,种子链接:'+downloadurl+',当前网址:'+web.driver.current_url+'且成功审核第'+file1.episodename+'集的资源'
         logger.info(infostr)
         return True,infostr
     else:
         logger.info('未成功审核第'+file1.episodename+'集的资源')
-        return True,fileinfo+'种子发布成功,种子链接:'+downloadurl+',当前网址:'+web.driver.current_url+'但未成功审核第'+file1.episodename+'集的资源'
-    
+        return True,fileinfo+'审核失败,种子链接:'+downloadurl+',当前网址:'+web.driver.current_url+'但未成功审核第'+file1.episodename+'集的资源'
 
 
-def lemonhd_upload_tv(web,file1,record_path,qbinfo,basic):
+def lemonhd_upload_tv(web,file1,record_path,qbinfo,basic,hashlist):
 
     if (file1.pathinfo.type=='anime' or file1.pathinfo.type=='tv') and file1.pathinfo.collection==0:
         fileinfo=file1.chinesename+'在'+web.site.sitename+'第'+file1.episodename+'集'
@@ -873,12 +874,14 @@ def lemonhd_upload_tv(web,file1,record_path,qbinfo,basic):
     if not downloadurl =='':
 
         #res=qbseed(url=downloadurl,filepath=file1.downloadpath,qbinfo=qbinfo)
-        res=qbseed(url=downloadurl,filepath=file1.downloadpath,qbinfo=qbinfo,category=file1.pathinfo.category)
+        res=qbseed(url=downloadurl,filepath=file1.downloadpath,qbinfo=qbinfo,category=file1.pathinfo.category,hashlist=hashlist)
         if res:
             logger.info(fileinfo+'种子发布成功,种子链接:'+downloadurl+',当前网址:'+web.driver.current_url)
+            fileinfo=fileinfo+'种子发布成功,'
         else:
             logger.warning(fileinfo+'添加种子失败,种子链接:'+downloadurl+',当前网址:'+web.driver.current_url)
-            return True,fileinfo+'种子发布成功,但是添加种子失败,请手动添加种子，种子链接:'+downloadurl+',当前网址:'+web.driver.current_url
+            fileinfo=fileinfo+'种子发布成功,但是添加种子失败,请手动添加种子,'
+            #return True,fileinfo+'种子发布成功,但是添加种子失败,请手动添加种子，种子链接:'+downloadurl+',当前网址:'+web.driver.current_url
     else:
         logger.warning(fileinfo+'未找到下载链接,当前网址:'+web.driver.current_url)
         return False,fileinfo+'未找到下载链接,当前网址:'+web.driver.current_url
@@ -887,18 +890,18 @@ def lemonhd_upload_tv(web,file1,record_path,qbinfo,basic):
     #return True,fileinfo+'种子发布成功,种子链接:'+downloadurl+',当前网址:'+web.driver.current_url
     
     if 'check' in dir(web.site) and web.site.check==False:
-        return True,fileinfo+'种子发布成功,种子链接:'+downloadurl+',当前网址:'+web.driver.current_url
+        return True,fileinfo+'种子链接:'+downloadurl+',当前网址:'+web.driver.current_url
 
     res=lemon_check(web)
 
     if res:
         logger.info('成功审核第'+file1.episodename+'集的资源')
-        infostr=fileinfo+'种子发布成功,种子链接:'+downloadurl+',当前网址:'+web.driver.current_url+'且成功审核第'+file1.episodename+'集的资源'
+        infostr=fileinfo+'审核成功,种子链接:'+downloadurl+',当前网址:'+web.driver.current_url+'且成功审核第'+file1.episodename+'集的资源'
         logger.info(infostr)
         return True,infostr
     else:
         logger.info('未成功审核第'+file1.episodename+'集的资源')
-        return True,fileinfo+'种子发布成功,种子链接:'+downloadurl+',当前网址:'+web.driver.current_url+'但未成功审核第'+file1.episodename+'集的资源'
+        return True,fileinfo+'审核失败,种子链接:'+downloadurl+',当前网址:'+web.driver.current_url+'但未成功审核第'+file1.episodename+'集的资源'
     
 
 
